@@ -25,7 +25,7 @@
 from webob import Request, Response
 from urlrelay import url, URLRelay
 from static import Cling
-from urllib import unquote
+from urllib import unquote, unquote_plus
 
 status_map = {
     200: "200 OK",
@@ -75,17 +75,25 @@ def expose(url_pattern, method='GET', content_type='text/html', charset='UTF-8')
 #
 
 def params(env, method):
-    data = None
-    params = {}
+    data       = None
+    _unquote   = None
+    params     = {}
+    params_raw = {}
+
     if method == 'GET':
-        data = env['QUERY_STRING']
+        data     = env['QUERY_STRING']
+        _unquote = unquote
     elif method == 'POST':
-        data = env['wsgi.input'].read()
+        data     = env['wsgi.input'].read()
+        _unquote = unquote_plus
     if data != None and data != '':
         for keyval in data.split('&'):
             k,v = keyval.split('=')
-            params[unquote(k)] = unquote(v)
+            params_raw[k] = v
+            params[_unquote(k)] = _unquote(v)
+            
     env['params'] = params
+    env['params_raw'] = params_raw
 
 
 ## Make the application
